//[mahjong-utils](../../index.md)/[mahjongutils.models.hand](index.md)

# Package-level declarations

## Types

| Name | Summary |
|---|---|
| [ChitoiHandPattern](-chitoi-hand-pattern/index.md) | [common]<br>@Serializable<br>@SerialName(value = &quot;ChitoiHandPattern&quot;)<br>data class [ChitoiHandPattern](-chitoi-hand-pattern/index.md)(val pairs: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../mahjongutils.models/-tile/index.md)&gt;, val remaining: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../mahjongutils.models/-tile/index.md)&gt;) : [IChitoiHandPattern](-i-chitoi-hand-pattern/index.md), [CommonHandPattern](-common-hand-pattern/index.md)<br>以七对子为目标的手牌 |
| [CommonHandPattern](-common-hand-pattern/index.md) | [common]<br>@Serializable<br>interface [CommonHandPattern](-common-hand-pattern/index.md) : [HandPattern](-hand-pattern/index.md) |
| [Hand](-hand/index.md) | [common]<br>@Serializable<br>data class [Hand](-hand/index.md)&lt;out [P](-hand/index.md) : [CommonHandPattern](-common-hand-pattern/index.md)&gt;(val tiles: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../mahjongutils.models/-tile/index.md)&gt;, val furo: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Furo](../mahjongutils.models/-furo/index.md)&gt;, val patterns: [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[P](-hand/index.md)&gt;) : [IHasFuro](-i-has-furo/index.md)<br>手牌 |
| [HandPattern](-hand-pattern/index.md) | [common]<br>interface [HandPattern](-hand-pattern/index.md) : [IHasFuro](-i-has-furo/index.md)<br>手牌形 |
| [IChitoiHandPattern](-i-chitoi-hand-pattern/index.md) | [common]<br>interface [IChitoiHandPattern](-i-chitoi-hand-pattern/index.md) : [HandPattern](-hand-pattern/index.md)<br>以七对子为目标的手牌 |
| [IHasFuro](-i-has-furo/index.md) | [common]<br>interface [IHasFuro](-i-has-furo/index.md) |
| [IKokushiHandPattern](-i-kokushi-hand-pattern/index.md) | [common]<br>interface [IKokushiHandPattern](-i-kokushi-hand-pattern/index.md) : [HandPattern](-hand-pattern/index.md)<br>以国士无双为目标的手牌 |
| [IRegularHandPattern](-i-regular-hand-pattern/index.md) | [common]<br>interface [IRegularHandPattern](-i-regular-hand-pattern/index.md) : [HandPattern](-hand-pattern/index.md)<br>以标准形为目标的手牌 |
| [KokushiHandPattern](-kokushi-hand-pattern/index.md) | [common]<br>@Serializable<br>@SerialName(value = &quot;KokushiHandPattern&quot;)<br>data class [KokushiHandPattern](-kokushi-hand-pattern/index.md)(val yaochu: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../mahjongutils.models/-tile/index.md)&gt;, val repeated: [Tile](../mahjongutils.models/-tile/index.md)?, val remaining: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../mahjongutils.models/-tile/index.md)&gt;) : [IKokushiHandPattern](-i-kokushi-hand-pattern/index.md), [CommonHandPattern](-common-hand-pattern/index.md)<br>以国士无双为目标的手牌 |
| [RegularHandPattern](-regular-hand-pattern/index.md) | [common]<br>@Serializable<br>@SerialName(value = &quot;RegularHandPattern&quot;)<br>data class [RegularHandPattern](-regular-hand-pattern/index.md)(val k: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), val jyantou: [Tile](../mahjongutils.models/-tile/index.md)?, val menzenMentsu: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Mentsu](../mahjongutils.models/-mentsu/index.md)&gt;, val furo: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Furo](../mahjongutils.models/-furo/index.md)&gt;, val tatsu: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tatsu](../mahjongutils.models/-tatsu/index.md)&gt;, val remaining: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../mahjongutils.models/-tile/index.md)&gt;) : [IRegularHandPattern](-i-regular-hand-pattern/index.md), [CommonHandPattern](-common-hand-pattern/index.md)<br>以标准形为目标的手牌 |
